local deforestation = ...

--self-destruct component
-------------------------------------
local COMP_SELF_DESTRUCT = {
	TypeName = "COMP_SELF_DESTRUCT",
	ParentType = "COMPONENT"
}
function COMP_SELF_DESTRUCT:update()
	self:getOwner():getParent():destroy()
end
deforestation:registerClass(COMP_SELF_DESTRUCT)


--register prefabs and their components
-----------------------------------------------------------------------
local parts = {
	["SMALL_DEFORESTATION_PART"] = {
		["path"] = "models/deforestation.fbx/Prefab/small_deforestation_part",
		["size"] = 12.5
	},
	["MEDIUM_DEFORESTATION_PART"] = {
		["path"] = "models/deforestation.fbx/Prefab/medium_deforestation_part",
		["size"] = 25
	},
	["LARGE_DEFORESTATION_PART"] = {
		["path"] = "models/deforestation.fbx/Prefab/large_deforestation_part",
		["size"] = 50
	}
}

for key, value in pairs(parts) do
    deforestation:registerAssetId(value["path"],"PREFAB_"..key)
	deforestation:registerPrefabComponent(value["path"], {
		DataType = "COMP_SELF_DESTRUCT"
	})
	deforestation:registerPrefabComponent(value["path"], {
		DataType = "COMP_BUILDING_PART"
	})
end


--register assets
---------------------------------------------------------------------
for key, value in pairs(parts) do
	deforestation:register({
		DataType = "BUILDING_PART",
		Id = key,
		Name = key.."_NAME",
		Description = key.."_DESC",
		Category = "CORE",
		ConstructorData = {
			DataType = "BUILDING_CONSTRUCTOR_DEFAULT",
			CoreObjectPrefab = "PREFAB_"..key
		},
		BuildingZone = {
			ZoneEntryList = {
				{
					Polygon = polygon.createCircle(value["size"],{0,0},6),
					Type = {
						DEFAULT = true,
						NAVIGABLE = true,
						GRASS_CLEAR = false
					}
				}
			}
		}
	})
end

	deforestation:register({
		DataType = "BUILDING_PART",
		Id = "DEFORESTATION_ROOT_PART",
		Name = "DEFORESTATION_ROOT_PART_NAME",
		Description = "DEFORESTATION_ROOT_PART_DESC",
		Category = "CORE",
		ConstructorData = {
			DataType = "BUILDING_CONSTRUCTOR_DEFAULT",
			CoreObjectPrefab = "PREFAB_SMALL_DEFORESTATION_PART"
		},
		IsVisibleWhenBuilt = false
	})

deforestation:register({
	DataType = "BUILDING",
	Id = "FE_MONUMENT_DEFORESTATION",
	Name = "DEFORESTATION_MONUMENT_NAME",
	Description = "DEFORESTATION_MONUMENT_DESC",
	BuildingType = "MONUMENT",
	AssetCoreBuildingPart = "DEFORESTATION_ROOT_PART",
	BuildingPartSetList = {
		{
			Name = "LIST_DEFORESTATION_NAME",
	        BuildingPartList = {
				"SMALL_DEFORESTATION_PART",
				"MEDIUM_DEFORESTATION_PART",
				"LARGE_DEFORESTATION_PART"
			}
		}
    },
	IsClearTrees = true
})